
#include <xc.h>
#include "adc1.h"
#include <stdint.h>
#include <stdbool.h>


 /*********************************************************************
 * 函數 : ADC_Read10bit(ADC_CHANNEL channel);
 *
 * 說明 : 讀取所設定 ADC 輸入通道 (AN12, RC0) 可變電阻上的數值後傳回 10-bit 的轉換數值
 *
 * 輸入 : ADC_CHANNEL channel - 使用列舉方式宣告 (adc1.h) 輸入的通道列舉成員識別字
 *        可變電阻接至 AN12 (RC0)。
 typedef enum 
{
    ADC1_CHANNEL_AN12 =  0xC,
    ADC1_CHANNEL_AVSS =  0xD,
    ADC1_CHANNEL_AVDD =  0xE,
    ADC1_CHANNEL_VBG =  0x1C,
    ADC1_MAX_CHANNEL_COUNT = 4
} ADC1_CHANNEL;
 
 *
 * 輸出 : uint16_t 向右靠齊的 10-bit 的 ADC 轉換值 或 錯誤值 0xFFFF
 *
 ********************************************************************/
uint16_t ADC_Read10bit ( ADC1_CHANNEL channel  )
{
    uint16_t i ;

    switch (channel)
    {
        case ADC1_CHANNEL_AN12:
            ANSELCbits.ANSC0 = 1;
            break ;

        default:
            return 0xFFFF ;
    }

    ADC1_ChannelSelect(channel) ;

    // Get an ADC sample
    ADC1_Start();                   //Start sampling
    for (i = 0 ; i < 1000 ; i++) ;  //Sample delay, conversion start automatically

    ADC1_Stop();                    //Stop sampling and Start Convert
    for (i = 0 ; i < 1000 ; i++) ;  //Sample delay, conversion start automatically

    while(!ADC1_IsConversionComplete()) ;       //Wait for conversion to complete

    return ADC1BUF0 ;
}     