/**
 專案名稱 : PIC32MM Lab5 SCCP2 PWM.x 
 主要功能 : 使用 MCC 來設定 SCCP 做 Dual Edge Compare 的 PWM 輸出

  軟體版本:
        Product Revision  :  MPLAB(c) Code Configurator - 3.15.0
        Device            :  PIC32MM0064GPL036
        Compiler          :  XC32 1.42
        MPLAB             :  MPLAB X 3.35
 */

/*
    (c) 2016 Microchip Technology Inc. and its subsidiaries. 

    本軟體是由 Microchip 公司所提供的範例程式。 Microchip 不保證其功能性的完整，
    且本範例程式僅是用來展示其功能，對於任何侵權或相關版權及軟體的錯誤所導致損失
    ，損害，費用和開支等 Microchip 均不具賠償責任。

    注意 : 您必須接收上述條款後方能使用此範例程式。
 */

/* CCP2CON2bits.OCAEN 位元為 PWM 輸出腳設定位元，此位元的設定是在"Registers" 裡設定的，
 * 將此位元設為 1 後方有輸出。 
 * Data sheet 的說明如下:
 
    OC<F:A>EN: Output Enable/Steering Control bits(1)
        1 = OCx pin is controlled by the CCPx module and produces an output compare or PWM signal
        0 = OCx pin is not controlled by the CCPx module; the pin is available to the port logic or another
        peripheral multiplexed on the pin
  
    Note 1: OCBEN 到 OCFEN (bits<25:29>) 僅使用在 MCCP 多個輸出模式，如:半橋(OCA & OCB)，全橋輸出 OCA ~ OCD
 *
         2. Each of the output pins controlled by the MCCP module may be enabled separately, using the
         OCxEN control bits (CCPxCON2<29:24>). Each of the bits, OCAEN through OCFEN, control a
         corresponding CCP output: OCxA through OCxF. If the OCxEN control bit is set, the corresponding
         I/O pin receives the output compare signal that is generated by the module.
         
 */

#include "mcc_generated_files/mcc.h"
#include "lcd.h"                    // LCD 函數原型宣告
#include "App.h"
#include <stdio.h>                  // 使用到 itoa() 函數
#include <string.h>

volatile unsigned int LCD_Update;   // LCD 顯示用旗號，Timer1 中斷時使用
char Disp_String[6];                // itoa() 轉換後的儲存陣列
char Received_Data;                 // UART2 接收的暫存資料 (中斷接收))
unsigned char UARTBuffer[100];


union {                             // 規劃 ADC1 轉換使用的共用變數的宣告
    unsigned int AD_10bit;          // 儲存 12-bit ADC1 的轉換值

    struct {
        unsigned char AD_LSB;       // 分割 12-bit ADC1 MSB 的值
        unsigned char AD_MSB;       // 分割 12-bit ADC1 LSB 的值
    } AD_Byte;
} ADC_Result;

const char * Disp_Line[4] =         // 在 Flash 所宣告的 LCD 顯示資料
{                                   // 使用指標陣列方式宣告
    "SCCP2 Dual Edge  ",
    "Press S1 to Cont.",
    "Lab5 PWM Output  ",
    "ADC1 =           ",
};

const char * TER_Line[5] =          // 在 Flash 所宣告的 Terminal 顯示資料
{                                   // 使用指標陣列方式宣告
    "Clear Terminal Screen",
    "Press S1 to Start the Dual Edge PWM outout ",
    "Read the Potentiometer (AN12) = ",
    "UART2 received a Character = ",
};

void main(void) {
    // initialize the device
    SYSTEM_Initialize();

    // When using interrupts, you need to set the Global Interrupt Enable bits
    // Use the following macros to:

    // Enable the Global Interrupts
    INTERRUPT_GlobalEnable();       // 開啟 Global 中斷  

    // Disable the Global Interrupts
    //INTERRUPT_GlobalDisable();
    

    VT100_Clear_Screen();           // 清除終端機畫面

    LCD_Initialize();               // LCD 模組初始設定 (4-bit Mode)

    LCD_Set_Cursor(0, 0);           // LCD 游標在(0,0) 位置
    putrsLCD(Disp_Line[0]);         // LCD 顯示 "UART Application"
    LCD_Set_Cursor(1, 0);           // LCD 游標在第二行第一個位置
    putrsLCD(Disp_Line[1]);         // LCD 顯示  "  Press S3 ...  " 

    Send_CR_LF();                   // 在終端機顯示 "Clear Terminal Screen",
   
    if (!UART2_TransmitBufferIsFull())      // 檢查 Tx Buffer 是否已滿
    {
        UART2_WriteBuffer(TER_Line[0], strlen(TER_Line[0]));

    }

    Send_CR_LF();                   // 在終端機顯示 "Press S3 to Continue ...  ",
    
    UART2_WriteBuffer(TER_Line[1], strlen(TER_Line[1]));
    Send_CR_LF();

    while (SW1_GetValue());          // 等待 SW1 被按下
                                    // S3_GetValue() 在 pin_manager.h 裡宣告
    LCD_Set_Cursor(0, 0);
    putrsLCD(Disp_Line[2]);         // LCD 顯示 "Lab4 Test UART2 "
    LCD_Set_Cursor(1, 0);
    putrsLCD(Disp_Line[3]);         // LCD 顯示 "ADC1 =          "

    LCD_Update = 0;
    
    while (1) {
        // 檢查接收狀態
        if (!UART2_ReceiveBufferIsEmpty())  // 檢查接收 Buffer 是否有資料? 
        {
            Received_Data = UART2_Read();   // 讀取接收 Buffer 一個 Byte 的資料
            UART2_WriteBuffer(TER_Line[3], strlen(TER_Line[3]));        // 先送出 "UART2 received a Character = " 到終端機
            UART2_Write(Received_Data);     // 送出所接收到的資料到終端機顯示
            Send_CR_LF();                   // 送出終端機換行及歸零命令
        }
        // 定期送出 LCD 的更新及終端機的更新顯示        
        if (LCD_Update)                     // 檢查 0.5S 的計時到了嗎?
        {                                   // 是，0.5S 已到，更新 LCD 的顯示
            LCD_Update = 0;
                                            // 讀取可變電阻上的轉換值
            ADC_Result.AD_10bit = ADC_Read10bit(ADC1_CHANNEL_AN12);

            LCD_Set_Cursor(1, 7);           // LCD 游標移到第二行第八個位置
            putcLCD('0');
            putcLCD('x');
            puthexLCD(ADC_Result.AD_Byte.AD_MSB);       // 以 Hex 格式顯示 ADC 轉換結果
            puthexLCD(ADC_Result.AD_Byte.AD_LSB);

            UART2_WriteBuffer(TER_Line[2], strlen(TER_Line[2]));        // 顯示  "Read the Potentiometer (AN12) = " 
            VT100_puthex(ADC_Result.AD_Byte.AD_MSB);    // 以 Hex 格式在終端機顯示 ADC 轉換結果
            VT100_puthex(ADC_Result.AD_Byte.AD_LSB);
            Send_CR_LF();                               // 送出終端機換行及歸零命令
            
            CCP2RB = ADC_Result.AD_10bit;               // ADC 轉換值來設定 PWM 的 Duty Cycle
            if (!UART2_TransmitBufferIsFull())
            {                                           // 利用 sprintf() 做字串與 Duty 百分比的計算後，自 UART2 送出
                sprintf(UARTBuffer, "\r\nPWM Duty Cycle =  %d%%\r\n\r\n", (CCP2RB*100)/CCP2PR); // 其中的 %% 適用來顯示 % 百分比用的
                UART2_WriteBuffer(UARTBuffer, strlen(UARTBuffer));      // 用 Write Buffer 方式將轉好的字串以中斷方式傳送去
            }
        }
    }
}
/**
 End of File
 */